#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 named-text
version:              1.2.2.0
visibility:           public
id:                   named-text-1.2.2.0-KnI9Ak2TMFL9lt7zBFfkGG
key:                  named-text-1.2.2.0-KnI9Ak2TMFL9lt7zBFfkGG
license:              ISC
copyright:            Galois Inc, 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:
    A parameterized named text type and associated functionality.

description:

    A plain String or Text is dangerous because it can be arbitrarily combined,
    converted, emitted, and updated without consideration of the validity and
    applicability of the contents and the usage scenario.

    This module provides a Named type wrapper around Text which has two
    additional type parameters: one which indicates what the content of the Text
    represents, and one which indicates the style of the name.

    There are additionally functions and classes which allow conversions and
    transformations between names with different styles and types (or disallow them
    where appropriate).

    The core intent of this library is that the Named is used instead of a raw
    String or Text to provide type-level tracking and safety.

category:             Data
abi:                  fba39d9bc9ff36a7d281da92710046d1
exposed:              True
exposed-modules:      Data.Name Data.Name.JSON
hidden-modules:       Data.Name.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/named-text-1.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/named-text-1.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/named-text-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-named-text
hs-libraries:         HSnamed-text-1.2.2.0-KnI9Ak2TMFL9lt7zBFfkGG
depends:
    aeson-2.2.1.0-CAI92PkToAUJ8bQ51mPxny base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1EYHMTe3sguJKzGBA0h7hZ
    prettyprinter-1.7.1-GiZuScg817SGeNuRUeFCVg
    sayable-1.2.6.0-3RP2sFhlgEWKlOt2gRXwIb text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-named-text/html/named-text.haddock
haddock-html:         /usr/share/doc/haskell-named-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

